<?php
// $Id$
/**
* Add include and setting files
*/
require_once(drupal_get_path('theme', 'mobile_jquery') . '/theme-settings.php');
require_once(drupal_get_path('theme', 'mobile_jquery') . '/includes/menu.inc');
require_once(drupal_get_path('theme', 'mobile_jquery') . '/includes/pager.inc');
require_once(drupal_get_path('theme', 'mobile_jquery') . '/includes/form.inc');
require_once(drupal_get_path('theme', 'mobile_jquery') . '/includes/comment.inc');

/**
 * Initialize theme settings
 */
global $theme_key;
if (db_is_active()) {
  mobile_jquery_initialize_theme_settings($theme_key);
}


/**
 * Implementation of template_preprocess_page()
 *
 * Process variables for page.tpl.php
 *
 * Most themes utilize their own copy of page.tpl.php. The default is located
 * inside "modules/system/page.tpl.php". Look in there for the full list of
 * variables.
 *
 * Uses the arg() function to generate a series of page template suggestions
 * based on the current path.
 *
 * Any changes to variables in this preprocessor should also be changed inside
 * template_preprocess_maintenance_page() to keep all them consistent.
 *
 * The $variables array contains the following arguments:
 * - $content
 * - $show_blocks
 *
 * @see page.tpl.php
 */
function mobile_jquery_preprocess_page(&$vars) {

	$vars['data_theme'] = theme_get_setting('data_theme');
	$vars['front_ron'] = theme_get_setting('front_ron');
	$vars['data_fullscreen'] = theme_get_settings('data_fullscreen');
	$vars['list_item_inset'] = theme_get_setting('list_item_inset');
	$vars['list_item_theme'] = theme_get_setting('list_item_theme');
	$vars['list_item_dividertheme'] = theme_get_setting('list_item_dividertheme');
	$vars['list_item_counttheme'] = theme_get_setting('list_item_counttheme');
	$vars['list_item_splittheme'] = theme_get_setting('list_item_splittheme');
	$vars['list_item_icon'] = theme_get_setting('list_item_icon');
	
	$vars['menu_item_inset'] = theme_get_setting('menu_item_inset');
	$vars['menu_item_theme'] = theme_get_setting('menu_item_theme');
	$vars['menu_item_dividertheme'] = theme_get_setting('menu_item_dividertheme');
	$vars['menu_item_counttheme'] = theme_get_setting('menu_item_counttheme');
	$vars['menu_item_splittheme'] = theme_get_setting('menu_item_splittheme');
	$vars['menu_item_icon'] = theme_get_setting('menu_item_icon');
	
	$vars['header_data_theme'] = theme_get_setting('header_data_theme');
	$vars['header_data_position'] = theme_get_setting('header_data_position');
	$vars['content_data_theme'] = theme_get_setting('content_data_theme');
	$vars['footer_data_theme'] = theme_get_setting('footer_data_theme');
	$vars['footer_data_position'] = theme_get_setting('footer_data_position');
	
	if(theme_get_setting('front_ron') && drupal_is_front_page()) {
		$vars['content'] = '<ul data-role="listview">' . $vars['content'] . '</ul>';
	}
	
	
}

/**
 * Implementation of template_preprocess_node()
 *
 * Process variables for node.tpl.php
 *
 * Most themes utilize their own copy of node.tpl.php. The default is located
 * inside "modules/node/node.tpl.php". Look in there for the full list of
 * variables.
 *
 * The $variables array contains the following arguments:
 * - $node
 * - $teaser
 * - $page
 *
 * @see node.tpl.php
 */
function mobile_jquery_preprocess_node(&$variables) {
  $node = $variables['node'];

  if ($variables['teaser'] && $node->teaser) {
	  if(theme_get_setting('front_ron') && drupal_is_front_page()) {
		  $variables['content'] = '<li data-icon="'.theme_get_setting('item_list_icon').'"><h2><a href="' . $node->path . '">' . $node->title . '</a></h2>' . $node->teaser . '</li>';
	  } else {
	    $variables['content'] = $node->teaser;
    }
  }
  elseif (isset($node->body)) {
    $variables['content'] = $node->body;
  }
  else {
    $variables['content'] = '';
  }

}

/**
 * Implementation of theme_item_list()
 *
 * @param $items
 *   An array of items to be displayed in the list. If an item is a string,
 *   then it is used as is. If an item is an array, then the "data" element of
 *   the array is used as the contents of the list item. If an item is an array
 *   with a "children" element, those children are displayed in a nested list.
 *   All other elements are treated as attributes of the list item element.
 * @param $title
 *   The title of the list.
 * @param $type
 *   The type of list to return (e.g. "ul", "ol")
 * @param $attributes
 *   The attributes applied to the list element.
 * @return
 *   A string containing the list output.
 */
function mobile_jquery_item_list($items = array(), $title = NULL, $type = 'ul', $attributes = NULL) {
  $output = '';
  
  if (!empty($items)) {
    $output .= "<$type". drupal_attributes($attributes) .' data-role="listview" data-inset="' . theme_get_setting('list_item_inset') . '" data-theme="' . theme_get_setting('list_item_theme') . '" data-dividertheme="' . theme_get_setting('list_item_dividertheme') . '"  data-splittheme="' . theme_get_setting('list_item_splittheme') . '"  data-counttheme="' . theme_get_setting('list_item_counttheme') . '">';
	  if (isset($title)) {
	    $output .= '<li data-role="list-divider">'. $title .'</li>';
	  }
    $num_items = count($items);
    foreach ($items as $i => $item) {
      $attributes = array();
      $children = array();
      
      if (is_array($item)) {
        foreach ($item as $key => $value) {
          if ($key == 'data') {
            $data = $value;
          }
          elseif ($key == 'children') {
            $children = $value;
          }
          else {
            $attributes[$key] = $value;
          }
        }
      }
      else {
        $data = $item;
      }
      
      if (count($children) > 0) {
        $data .= mobile_jquery_item_list($children, NULL, $type, $attributes); // Render nested list
      }

      $output .= '<li'. drupal_attributes($attributes) .' data-icon="' . theme_get_setting('list_item_icon') . '">'. $data ."</li>\n";
    }
    $output .= "</$type>";
  }
  $output .= "\n";
  return $output;
}

/**
 * Implementation of theme_links()
 * 
 * Return a themed set of links.
 *
 * @param $links
 *   A keyed array of links to be themed.
 * @param $attributes
 *   A keyed array of attributes
 * @return
 *   A string containing an unordered list of links.
 */
function mobile_jquery_links($links, $attributes = array('class' => 'links')) {
  global $language;
  $output = '';
  
  foreach($links as $key => $value) {
  	if(isset($links[$key]['fragment'])) {
	  	unset($links[$key]['fragment']);
  	}
  }
  
  if (count($links) > 0) {
    $output = '<ul'. drupal_attributes($attributes) .'>';

    $num_links = count($links);
    $i = 1;

    foreach ($links as $key => $link) {
      $class = $key;

      // Add first, last and active classes to the list of links to help out themers.
      if ($i == 1) {
        $class .= ' first';
      }
      if ($i == $num_links) {
        $class .= ' last';
      }
      if (isset($link['href']) && ($link['href'] == $_GET['q'] || ($link['href'] == '<front>' && drupal_is_front_page()))
          && (empty($link['language']) || $link['language']->language == $language->language)) {
        $class .= ' active';
      }
      $output .= '<li'. drupal_attributes(array('class' => $class)) .'>';

      if (isset($link['href'])) {
        // Pass in $link as $options, they share the same keys.
        $output .= l($link['title'], $link['href'], $link);
      }
      else if (!empty($link['title'])) {
        // Some links are actually not links, but we wrap these in <span> for adding title and class attributes
        if (empty($link['html'])) {
          $link['title'] = check_plain($link['title']);
        }
        $span_attributes = '';
        if (isset($link['attributes'])) {
          $span_attributes = drupal_attributes($link['attributes']);
        }
        $output .= '<span'. $span_attributes .'>'. $link['title'] .'</span>';
      }

      $i++;
      $output .= "</li>\n";
    }

    $output .= '</ul>';
  }

  return $output;
}
